@@ -2,7 +2,7 @@
 /*-----------------------------------------------------------------------------
 cheetan is licensed under the MIT license.
 copyright (c) 2006 cheetan all right reserved.
-http://www.cheetan.net/
+http://php.cheetan.net/
 -----------------------------------------------------------------------------*/
 	require_once LIBDIR . DIRECTORY_SEPARATOR . "object.php";
 	require_once LIBDIR . DIRECTORY_SEPARATOR . "database.php";
@@ -15,6 +15,7 @@ http://www.cheetan.net/
 	require_once LIBDIR . DIRECTORY_SEPARATOR . "db" . DIRECTORY_SEPARATOR . "common.php";
 	require_once LIBDIR . DIRECTORY_SEPARATOR . "db" . DIRECTORY_SEPARATOR . "mysql.php";
 	require_once LIBDIR . DIRECTORY_SEPARATOR . "db" . DIRECTORY_SEPARATOR . "pgsql.php";
+	require_once LIBDIR . DIRECTORY_SEPARATOR . "db" . DIRECTORY_SEPARATOR . "txtsql.php";
 	
 	if( !defined( "SCRIPTFILE" ) )
 	{
