@@ -2,7 +2,7 @@
 /*-----------------------------------------------------------------------------
 cheetan is licensed under the MIT license.
 copyright (c) 2006 cheetan all right reserved.
-http://www.cheetan.net/
+http://php.cheetan.net/
 -----------------------------------------------------------------------------*/
 class CModel extends CObject
 {
@@ -35,91 +35,55 @@ class CModel extends CObject
 	}
 	
 	
-	function findquery( $query, $condition = "", $order = "", $group = "" )
+	function findquery( $query, $condition = "", $order = "", $limit = "", $group = "" )
 	{
-		if( $condition )	$query .= " WHERE $condition";
-		if( $group )		$query .= " GROUP BY $group";
-		if( $order )		$query .= " ORDER BY $order";
-		return $this->db->find( $query, $this->name );
+		return $this->db->findquery( $query, $condition, $order, $limit, $group, $this->name );
 	}
 
 
-	function find( $condition = "", $order = "" )
+	function find( $condition = "", $order = "", $limit = "", $group = "" )
 	{
-		$query	= "SELECT * FROM $this->table";
-		return $this->findquery( $query, $condition, $order );
+		return $this->db->findall( $this->table, $condition, $order, $limit, $group, $this->name );
 	}
 	
 	
 	function findone( $condition = "", $order = "" )
 	{
-		$query	= "SELECT * FROM $this->table";
-		if( $condition )	$query .= " WHERE $condition";
-		if( $order )		$query .= " ORDER BY $order";
-		$result	= $this->db->find( $query, $this->name );
+		$result	= $this->find( $condition, $order, 1 );
 		if( count( $result ) )	return $result[0];
 		return FALSE;
 	}
 	
 	
+	function findby( $field, $value, $order = "", $limit = "" )
+	{
+		$condition	= $this->db->CreateCondition( $field, $value, $this->name );
+		return $this->find( $condition, $order, $limit );
+	}
+	
+	
+	function findoneby( $field, $value, $order = "" )
+	{
+		$condition	= $this->db->CreateCondition( $field, $value, $this->name );
+		return $this->findone( $condition, $order );
+	}
+	
+	
 	function getcount( $condition = "", $limit = "" )
 	{
-		$query	= "SELECT * FROM $this->table";
-		if( $condition )	$query .= " WHERE $condition";
-		if( $limit )		$query .= " LIMIT $limit";
-		return $this->db->count( $query, $this->name );
+		return $this->db->getcount( $this->table, $condition, $limit, $this->name );
 	}
 
 
 	function insert( $datas )
 	{
-		$count	= count( $datas );
-		$query	= "INSERT INTO $this->table(";
-		$i		= 0;
-		foreach( $datas as $key => $data )
-		{
-			$query .= "$key";
-			if( $i < $count - 1 )
-			{
-				$query .= ",";
-			}
-			$i++;
-		}
-		$query	.= ") VALUES(";
-		$i		= 0;
-		foreach( $datas as $key => $data )
-		{
-			$query .= "'$data'";
-			if( $i < $count - 1 )
-			{
-				$query .= ",";
-			}
-			$i++;
-		}
-		$query	.= ")";
-		return $this->query( $query );
+		return $this->db->insert( $this->table, $datas, $this->name );
 	}
 
 
 	function updateby( $datas, $condition )
 	{
-		$count	= count( $datas );
-		$query	= "UPDATE $this->table SET ";
-		$i		= 0;
-		foreach( $datas as $key => $data )
-		{
-			if( $key != $this->id )
-			{
-				$query .= "$key='$data'";
-				if( $i < $count - 1 )
-				{
-					$query .= ",";
-				}
-			}
-		}
-		$query	= substr( $query, 0, strlen( $query ) - 1 );
-		$query	.= " WHERE $condition";
-		return $this->query( $query );
+		return $this->db->update( $this->table, $datas, $condition, $this->name );
 	}
 	
 	
@@ -127,21 +91,10 @@ class CModel extends CObject
 	{
 		if( array_key_exists( $this->id, $datas ) )
 		{
-			$query	= "UPDATE $this->table SET ";
-			foreach( $datas as $key => $data )
-			{
-				if( $key == $this->id )
-				{
-					$condition	= " WHERE id=$data";
-				}
-				else
-				{
-					$query		.= "$key='$data',";
-				}
-			}
-			$query	= substr( $query, 0, strlen( $query ) - 1 );
-			$query	.= $condition;
-			return $this->query( $query );
+			$copy		= array_slice( $datas, 0 );
+			unset( $copy[$this->id] );
+			$condition	= $this->db->CreateCondition( $this->id, $datas[$this->id], $this->name );
+			return $this->updateby( $datas, $condition );
 		}
 		
 		return FALSE;
@@ -150,8 +103,7 @@ class CModel extends CObject
 
 	function del( $condition )
 	{
-		$query	= "DELETE FROM $this->table WHERE $condition";
-		return $this->query( $query );
+		return $this->db->del( $this->table, $condition, $this->name );
 	}
 	
 	
